@@ -26,24 +26,30 @@ class Download:
     def __init__(self, repo: DownloadRepo, success_prefix: str):
         self._repo = repo
         self._success_prefix = success_prefix
-        self._name_width_max = 0
 
     def find_download_and_install(self, mods: Sequence[Mod]) -> None:
-        mods_to_install = self._find_latest_versions(mods)
-        self._download_and_install(mods_to_install)
-
-    def _find_latest_versions(self, mods: Sequence[Mod]) -> Sequence[DownloadInfo]:
-        mods_to_install: List[DownloadInfo] = []
         mods_not_found: List[ModNotFoundException] = []
 
         # Find latest version of mod
         for mod in mods:
             try:
+                Logger.info(mod.id, LogColors.bold)
                 latest_version = self._repo.get_latest_version(mod)
-                download_info = DownloadInfo(mod, latest_version)
-                mods_to_install.append(download_info)
+
+                if latest_version:
+                    download_info = DownloadInfo(mod, latest_version)
+                    Logger.verbose("⬇ Downloading...", indent=1)
+                    self._download_and_install(download_info)
+                    Logger.info(
+                        f"🟢 {self._success_prefix} -> {download_info.version_info.filename}",
+                        LogColors.green,
+                        indent=1,
+                    )
+                else:
+                    Logger.verbose("🟨 No new version found", LogColors.skip, indent=1)
 
             except ModNotFoundException as exception:
+                Logger.error("🔺 Mod not found on any site...", indent=1)
                 mods_not_found.append(exception)
 
         # Print errors
@@ -51,29 +57,11 @@ class Download:
             errorMessage = ""
             for error in mods_not_found:
                 errorMessage += str(error) + "\n\n"
-            Logger.error(errorMessage, exit=True)
+            Logger.error(errorMessage)
 
-        return mods_to_install
-
-    def _download_and_install(self, downloads: Sequence[DownloadInfo]):
-        # Check max name width
-        for download_info in downloads:
-            name_width = len(download_info.name)
-            if name_width > self._name_width_max:
-                self._name_width_max = name_width
-
-        # Download
-        for download_info in downloads:
-            downloaded_mod = self._download(download_info.mod, download_info.version_info)
-            self._repo.update_mod(downloaded_mod)
-            self._print_installed(download_info)
-
-    def _print_installed(self, download_info: DownloadInfo) -> None:
-        name = download_info.name.ljust(self._name_width_max)
-        Logger.info(
-            f"{self._success_prefix} {name} -> {download_info.version_info.name}",
-            LogColors.green,
-        )
+    def _download_and_install(self, download_info: DownloadInfo) -> None:
+        downloaded_mod = self._download(download_info.mod, download_info.version_info)
+        self._repo.update_mod(downloaded_mod)
 
     def _download(self, mod: ModArg, latest_version: VersionInfo) -> Mod:
         downloaded_file = self._repo.download(latest_version.download_url, latest_version.filename)
